Submit Review on Capelayo Beach Restaurant | Eat & Drink in Mykonos | Mykonos, Cyclades, Greece
Author: ilove group ltd
Description: Selected local ingredients, creative Mediterranean cuisine, quality, superb location on Elia beach and unique atmosphere. Capelayo Restaurant is a must in the Mykonian food scene. The name Capelayo comes from the naval tradition of Mykonos ...
Keywords: Mykonos,Island,Greece,Resorts,Hotels,Villas,Bookings,Reviews,Holidays

- Restaurant Overview ×
- Restaurant Photos ×
- Restaurant Reviews ×
- View on Map ×

# Capelayo

Your Review
Review Title:

If you could say it in one sentence, what would it be? ( )

Your Rating:
Terrible Not That Bad Average Good Excellent
Would you recommend it to a friend:
No Yes
Your Review:

Share your experience with the world.

Good Points:

Did something please you? (255)

Bad Points:

Did something dissapoint you? (255)

A Little About You
Your Full Name:

Please provide your first and last name
*Your name will be visible to those reading your review.

Your Email Address:

Please provide a valid email address as it will be used to confirm your review
*Your email address will not be shown anywhere.

Where are you from:

Please provide city and country of residence (i.e. Yekaterinburg, Russian Federation)

Travelled As:
Season:
Review Confirmation
Please enter the text from the image to confirm your review:

#### Sleep Near By

- Myconian Imperial Hotel & Thalasso Spa 157 meters away
- Royal Myconian Resort & Thalasso Spa 236 meters away
- Greco Philia Luxury Suites & Villas 242 meters away
- Sunrise Hotel 754 meters away
- Agrari Beach Hotel 780 meters away

#### Eat & Drink Near By

- Elia Restaurant 82 meters away

#### Party Near By

- Cocktail Bar Agrari 715 meters away

#### See & Do Near By

- Elia Beach 116 meters away
- Elia Water Sports 138 meters away
- Water Action Sports 725 meters away
- Agrari Beach 753 meters away